window.Gleam.initSearch([{"doc":"immutable_lru","title":"immutable_lru","content":"# immutable_lru\n\n[![Package Version](https://img.shields.io/hexpm/v/immutable_lru)](https://hex.pm/packages/immutable_lru)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/immutable_lru/)\n\n```sh\ngleam add immutable_lru\n```\n```gleam\nimport immutable_lru\n\npub fn main() {\n  let c =\n    immutable_lru.new(10)\n    |&gt; immutable_lru.set(&quot;1&quot;, [&quot;first&quot;])\n    |&gt; immutable_lru.set(&quot;2&quot;, [&quot;second&quot;])\n    |&gt; immutable_lru.set(&quot;3&quot;, [&quot;third&quot;])\n\n  let val =\n    c\n    |&gt; immutable_lru.get(&quot;3&quot;)\n    |&gt; result.map(with: fn(x) {\n      let #(_, val) = x\n      val\n    })\n  // val == [&quot;third&quot;]\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/immutable_lru&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"immutable_lru","title":"LruCache","content":"pub opaque type LruCache(k, v)\n A dictionary of keys and values that follows the least recently updated\n cache replacement policy.\n\n Any type can be used for the keys and values of a dict, but all the keys\n must be of the same type and all the values must be of the same type.\n\n There is no guarantee of ordering of the collection.\n\n\nSynonyms:\nimmutable_lru.LruCache\nimmutable_lru LruCache","url":"immutable_lru.html#LruCache"},{"doc":"immutable_lru","title":"clear","content":"pub fn clear(c: LruCache(a, b)) -&gt; LruCache(a, b)\n Clear all entries in the cache. \n\n The `max` of the cache is reused.\n\n\n ## Examples\n\n \n  let c =\n    new(10)\n    |&gt; set(&quot;1&quot;, &quot;a&quot;)\n    |&gt; set(&quot;2&quot;, &quot;b&quot;)\n    |&gt; set(&quot;3&quot;, &quot;c&quot;)\n\n  let is_mem = has(c, &quot;3&quot;)\n  // is_mem == True\n\n  let c = clear(c)\n\n  let is_mem = has(c, &quot;3&quot;)\n  // is_mem == False\n \n\nSynonyms:\nimmutable_lru.clear\nimmutable_lru clear","url":"immutable_lru.html#clear"},{"doc":"immutable_lru","title":"get","content":"pub fn get(\n  c: LruCache(a, b),\n  key: a,\n) -&gt; Result(#(LruCache(a, b), b), Nil)\n Retrieve a value from the cache as a Result\n\n Returns a tuple to allow for further reads from the updated cache\n \n\n ## Examples\n\n \n new()\n  let c =\n    new(10)\n    |&gt; set(&quot;a&quot;, 1)\n    |&gt; set(&quot;b&quot;, 2)\n    |&gt; set(&quot;c&quot;, 3)\n  let #(c, val) = {\n    case get(c, &quot;a&quot;) {\n      Ok(pairs) -&gt; pairs\n      Error(_) -&gt; panic as &quot;whoops&quot;\n    }\n  }\n  let t = val == 1\n  // t == True\n \n\nSynonyms:\nimmutable_lru.get\nimmutable_lru get","url":"immutable_lru.html#get"},{"doc":"immutable_lru","title":"get_exn","content":"pub fn get_exn(c: LruCache(a, b), key: a) -&gt; #(LruCache(a, b), b)\n Retrieve a value from the cache or panic\n\n Returns a tuple to allow for further reads from the updated cache\n \n\n ## Examples\n\n \n new()\n  let c =\n    new(10)\n    |&gt; set(&quot;a&quot;, 1)\n    |&gt; set(&quot;b&quot;, 2)\n    |&gt; set(&quot;c&quot;, 3)\n  let #(c, val) = get_exn(c, &quot;a&quot;)\n  let t = val == 1\n  // t == True\n \n\nSynonyms:\nimmutable_lru.get_exn\nimmutable_lru get_exn","url":"immutable_lru.html#get_exn"},{"doc":"immutable_lru","title":"has","content":"pub fn has(c: LruCache(a, b), key: a) -&gt; Bool\n Check for membership in the cache\n\n\n ## Examples\n\n \n new()\n |&gt; set(&quot;a&quot;, 1)\n |&gt; set(&quot;b&quot;, 2)\n |&gt; has(&quot;b&quot;)\n // -&gt; True\n \n\nSynonyms:\nimmutable_lru.has\nimmutable_lru has","url":"immutable_lru.html#has"},{"doc":"immutable_lru","title":"new","content":"pub fn new(max: Int) -&gt; LruCache(a, b)\n Creates a new empty cache that will have at most 2n entries and will be \n immutably updated with the LRU policy.\n\n \n  let c =\n    new(10)\n    |&gt; set(&quot;a&quot;, 1)\n    |&gt; set(&quot;b&quot;, 2)\n    |&gt; set(&quot;c&quot;, 3)\n  let #(c, val) = {\n    case get(c, &quot;a&quot;) {\n      Ok(pairs) -&gt; pairs\n      Error(_) -&gt; panic as &quot;whoops&quot;\n    }\n  }\n  let t = val == 1\n  // t == True\n \n\nSynonyms:\nimmutable_lru.new\nimmutable_lru new","url":"immutable_lru.html#new"},{"doc":"immutable_lru","title":"set","content":"pub fn set(c: LruCache(a, b), key: a, value: b) -&gt; LruCache(a, b)\n Add an entry into the cache\n\n\n ## Examples\n\n \n new()\n  let c =\n    new(10)\n    |&gt; set(&quot;a&quot;, 1)\n    |&gt; set(&quot;b&quot;, 2)\n    |&gt; set(&quot;c&quot;, 3)\n  let #(c, val) = get_exn(c, &quot;a&quot;)\n  let t = val == 1\n  // t == True\n \n\nSynonyms:\nimmutable_lru.set\nimmutable_lru set","url":"immutable_lru.html#set"},{"doc":"immutable_lru","title":"immutable_lru","content":"","url":"immutable_lru.html"}]);